# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dborgproto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dborgproto.proto',
  package='dashborg.rpc1',
  syntax='proto3',
  serialized_options=b'Z.github.com/sawka/dashborg-go-sdk/pkg/dashproto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x64\x62orgproto.proto\x12\rdashborg.rpc1\"\xb4\x01\n\x08RRAction\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x12\n\nActionType\x18\x02 \x01(\t\x12\x10\n\x08Selector\x18\x03 \x01(\t\x12\x10\n\x08JsonData\x18\x04 \x01(\t\x12\x11\n\tEventType\x18\x05 \x01(\t\x12\x0c\n\x04Html\x18\x06 \x01(\t\x12\x0b\n\x03\x45rr\x18\x07 \x01(\t\x12\x11\n\tBlobBytes\x18\x08 \x01(\x0c\x12\x14\n\x0c\x42lobMimeType\x18\t \x01(\t\x12\r\n\x05ReqId\x18\n \x01(\t\"\xb9\x01\n\x13SendResponseMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\r\n\x05ReqId\x18\x02 \x01(\t\x12\x13\n\x0bRequestType\x18\x03 \x01(\t\x12\x11\n\tPanelName\x18\x04 \x01(\t\x12\x12\n\nFeClientId\x18\x05 \x01(\t\x12\x14\n\x0cResponseDone\x18\x06 \x01(\x08\x12(\n\x07\x41\x63tions\x18\x07 \x03(\x0b\x32\x17.dashborg.rpc1.RRAction\x12\x0b\n\x03\x45rr\x18\x08 \x01(\t\"\xda\x02\n\x0eRequestMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\r\n\x05\x41\x63\x63Id\x18\x02 \x01(\t\x12\x10\n\x08ZoneName\x18\x03 \x01(\t\x12\x11\n\tPanelName\x18\x04 \x01(\t\x12\x13\n\x0bRequestType\x18\x05 \x01(\t\x12\x0c\n\x04Path\x18\x06 \x01(\t\x12\r\n\x05ReqId\x18\x07 \x01(\t\x12\x12\n\nFeClientId\x18\x08 \x01(\t\x12\x11\n\tControlId\x18\t \x01(\t\x12\x10\n\x08JsonData\x18\n \x01(\t\x12\x10\n\x08\x41uthData\x18\x0b \x01(\t\x12\x16\n\x0ePanelStateData\x18\x0c \x01(\t\x12\x0b\n\x03\x45rr\x18\r \x01(\t\x12)\n\x07\x45rrCode\x18\x0e \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x11\n\tTimeoutMs\x18\x0f \x01(\x03\x12\x11\n\tDataPaths\x18\x10 \x03(\t\x12\x15\n\rIsBackendCall\x18\x11 \x01(\x08\"B\n\nHandlerKey\x12\x11\n\tPanelName\x18\x01 \x01(\t\x12\x13\n\x0bHandlerType\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\"Q\n\x16RegisterHandlerMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12+\n\x08Handlers\x18\x02 \x03(\x0b\x32\x19.dashborg.rpc1.HandlerKey\"b\n\x17RegisterHandlerResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\"\x9f\x03\n\x0bProcMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tProcRunId\x18\x02 \x01(\t\x12\r\n\x05\x41\x63\x63Id\x18\x03 \x01(\t\x12\x10\n\x08ZoneName\x18\x04 \x01(\t\x12\x0f\n\x07\x41nonAcc\x18\x05 \x01(\x08\x12\x10\n\x08ProcName\x18\x06 \x01(\t\x12:\n\x08ProcTags\x18\x07 \x03(\x0b\x32(.dashborg.rpc1.ProcMessage.ProcTagsEntry\x12:\n\x08HostData\x18\x08 \x03(\x0b\x32(.dashborg.rpc1.ProcMessage.HostDataEntry\x12\x0f\n\x07StartTs\x18\t \x01(\x03\x12+\n\x08Handlers\x18\n \x03(\x0b\x32\x19.dashborg.rpc1.HandlerKey\x12\x15\n\rClientVersion\x18\x0b \x01(\t\x1a/\n\rProcTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rHostDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x0cProcResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x0e\n\x06\x43onnId\x18\x04 \x01(\t\"\"\n\x14RequestStreamMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\"y\n\x14SendResponseResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12)\n\x07\x45rrCode\x18\x03 \x01(\x0e\x32\x18.dashborg.rpc1.ErrorCode\x12\x18\n\x10NumStreamClients\x18\x04 \x01(\x05\"^\n\x12StartStreamMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x12\n\nFeClientId\x18\x03 \x01(\t\x12\x15\n\rExistingReqId\x18\x04 \x01(\t\"B\n\x13StartStreamResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\r\n\x05ReqId\x18\x03 \x01(\t\" \n\x12ReflectZoneMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\"E\n\x13ReflectZoneResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\x10\n\x08JsonData\x18\x03 \x01(\t\"W\n\x16\x43\x61llDataHandlerMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x10\n\x08JsonData\x18\x04 \x01(\t\"I\n\x17\x43\x61llDataHandlerResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t\x12\x10\n\x08JsonData\x18\x03 \x01(\t\"A\n\x12\x42\x61\x63kendPushMessage\x12\n\n\x02Ts\x18\x01 \x01(\x03\x12\x11\n\tPanelName\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\"3\n\x13\x42\x61\x63kendPushResponse\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0b\n\x03\x45rr\x18\x02 \x01(\t*~\n\tErrorCode\x12\x0b\n\x07\x45\x43_NONE\x10\x00\x12\n\n\x06\x45\x43_EOF\x10\x01\x12\x0e\n\nEC_UNKNOWN\x10\x02\x12\x10\n\x0c\x45\x43_BADCONNID\x10\x03\x12\x10\n\x0c\x45\x43_ACCACCESS\x10\x04\x12\x10\n\x0c\x45\x43_NOHANDLER\x10\x05\x12\x12\n\x0e\x45\x43_UNAVAILABLE\x10\x06\x32\xd8\x05\n\x0f\x44\x61shborgService\x12\x41\n\x04Proc\x12\x1a.dashborg.rpc1.ProcMessage\x1a\x1b.dashborg.rpc1.ProcResponse\"\x00\x12Y\n\x0cSendResponse\x12\".dashborg.rpc1.SendResponseMessage\x1a#.dashborg.rpc1.SendResponseResponse\"\x00\x12\x62\n\x0fRegisterHandler\x12%.dashborg.rpc1.RegisterHandlerMessage\x1a&.dashborg.rpc1.RegisterHandlerResponse\"\x00\x12V\n\x0bStartStream\x12!.dashborg.rpc1.StartStreamMessage\x1a\".dashborg.rpc1.StartStreamResponse\"\x00\x12V\n\x0bReflectZone\x12!.dashborg.rpc1.ReflectZoneMessage\x1a\".dashborg.rpc1.ReflectZoneResponse\"\x00\x12\x62\n\x0f\x43\x61llDataHandler\x12%.dashborg.rpc1.CallDataHandlerMessage\x1a&.dashborg.rpc1.CallDataHandlerResponse\"\x00\x12V\n\x0b\x42\x61\x63kendPush\x12!.dashborg.rpc1.BackendPushMessage\x1a\".dashborg.rpc1.BackendPushResponse\"\x00\x12W\n\rRequestStream\x12#.dashborg.rpc1.RequestStreamMessage\x1a\x1d.dashborg.rpc1.RequestMessage\"\x00\x30\x01\x42\x30Z.github.com/sawka/dashborg-go-sdk/pkg/dashprotob\x06proto3'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='dashborg.rpc1.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EC_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_EOF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_BADCONNID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_ACCACCESS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_NOHANDLER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC_UNAVAILABLE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2241,
  serialized_end=2367,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
EC_NONE = 0
EC_EOF = 1
EC_UNKNOWN = 2
EC_BADCONNID = 3
EC_ACCACCESS = 4
EC_NOHANDLER = 5
EC_UNAVAILABLE = 6



_RRACTION = _descriptor.Descriptor(
  name='RRAction',
  full_name='dashborg.rpc1.RRAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RRAction.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ActionType', full_name='dashborg.rpc1.RRAction.ActionType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Selector', full_name='dashborg.rpc1.RRAction.Selector', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.RRAction.JsonData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EventType', full_name='dashborg.rpc1.RRAction.EventType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Html', full_name='dashborg.rpc1.RRAction.Html', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RRAction.Err', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BlobBytes', full_name='dashborg.rpc1.RRAction.BlobBytes', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BlobMimeType', full_name='dashborg.rpc1.RRAction.BlobMimeType', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.RRAction.ReqId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=216,
)


_SENDRESPONSEMESSAGE = _descriptor.Descriptor(
  name='SendResponseMessage',
  full_name='dashborg.rpc1.SendResponseMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.SendResponseMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.SendResponseMessage.ReqId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RequestType', full_name='dashborg.rpc1.SendResponseMessage.RequestType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.SendResponseMessage.PanelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.SendResponseMessage.FeClientId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ResponseDone', full_name='dashborg.rpc1.SendResponseMessage.ResponseDone', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Actions', full_name='dashborg.rpc1.SendResponseMessage.Actions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.SendResponseMessage.Err', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=404,
)


_REQUESTMESSAGE = _descriptor.Descriptor(
  name='RequestMessage',
  full_name='dashborg.rpc1.RequestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RequestMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AccId', full_name='dashborg.rpc1.RequestMessage.AccId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ZoneName', full_name='dashborg.rpc1.RequestMessage.ZoneName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.RequestMessage.PanelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RequestType', full_name='dashborg.rpc1.RequestMessage.RequestType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.RequestMessage.Path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.RequestMessage.ReqId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.RequestMessage.FeClientId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ControlId', full_name='dashborg.rpc1.RequestMessage.ControlId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.RequestMessage.JsonData', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AuthData', full_name='dashborg.rpc1.RequestMessage.AuthData', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelStateData', full_name='dashborg.rpc1.RequestMessage.PanelStateData', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RequestMessage.Err', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.RequestMessage.ErrCode', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TimeoutMs', full_name='dashborg.rpc1.RequestMessage.TimeoutMs', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='DataPaths', full_name='dashborg.rpc1.RequestMessage.DataPaths', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsBackendCall', full_name='dashborg.rpc1.RequestMessage.IsBackendCall', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=753,
)


_HANDLERKEY = _descriptor.Descriptor(
  name='HandlerKey',
  full_name='dashborg.rpc1.HandlerKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.HandlerKey.PanelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HandlerType', full_name='dashborg.rpc1.HandlerKey.HandlerType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.HandlerKey.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=821,
)


_REGISTERHANDLERMESSAGE = _descriptor.Descriptor(
  name='RegisterHandlerMessage',
  full_name='dashborg.rpc1.RegisterHandlerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RegisterHandlerMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Handlers', full_name='dashborg.rpc1.RegisterHandlerMessage.Handlers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=904,
)


_REGISTERHANDLERRESPONSE = _descriptor.Descriptor(
  name='RegisterHandlerResponse',
  full_name='dashborg.rpc1.RegisterHandlerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.RegisterHandlerResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.RegisterHandlerResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.RegisterHandlerResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=1004,
)


_PROCMESSAGE_PROCTAGSENTRY = _descriptor.Descriptor(
  name='ProcTagsEntry',
  full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dashborg.rpc1.ProcMessage.ProcTagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1373,
)

_PROCMESSAGE_HOSTDATAENTRY = _descriptor.Descriptor(
  name='HostDataEntry',
  full_name='dashborg.rpc1.ProcMessage.HostDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dashborg.rpc1.ProcMessage.HostDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dashborg.rpc1.ProcMessage.HostDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1375,
  serialized_end=1422,
)

_PROCMESSAGE = _descriptor.Descriptor(
  name='ProcMessage',
  full_name='dashborg.rpc1.ProcMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.ProcMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcRunId', full_name='dashborg.rpc1.ProcMessage.ProcRunId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AccId', full_name='dashborg.rpc1.ProcMessage.AccId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ZoneName', full_name='dashborg.rpc1.ProcMessage.ZoneName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AnonAcc', full_name='dashborg.rpc1.ProcMessage.AnonAcc', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcName', full_name='dashborg.rpc1.ProcMessage.ProcName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ProcTags', full_name='dashborg.rpc1.ProcMessage.ProcTags', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='HostData', full_name='dashborg.rpc1.ProcMessage.HostData', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='StartTs', full_name='dashborg.rpc1.ProcMessage.StartTs', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Handlers', full_name='dashborg.rpc1.ProcMessage.Handlers', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ClientVersion', full_name='dashborg.rpc1.ProcMessage.ClientVersion', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROCMESSAGE_PROCTAGSENTRY, _PROCMESSAGE_HOSTDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1422,
)


_PROCRESPONSE = _descriptor.Descriptor(
  name='ProcResponse',
  full_name='dashborg.rpc1.ProcResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.ProcResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.ProcResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.ProcResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ConnId', full_name='dashborg.rpc1.ProcResponse.ConnId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1527,
)


_REQUESTSTREAMMESSAGE = _descriptor.Descriptor(
  name='RequestStreamMessage',
  full_name='dashborg.rpc1.RequestStreamMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.RequestStreamMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1563,
)


_SENDRESPONSERESPONSE = _descriptor.Descriptor(
  name='SendResponseResponse',
  full_name='dashborg.rpc1.SendResponseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.SendResponseResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.SendResponseResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ErrCode', full_name='dashborg.rpc1.SendResponseResponse.ErrCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NumStreamClients', full_name='dashborg.rpc1.SendResponseResponse.NumStreamClients', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1686,
)


_STARTSTREAMMESSAGE = _descriptor.Descriptor(
  name='StartStreamMessage',
  full_name='dashborg.rpc1.StartStreamMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.StartStreamMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.StartStreamMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FeClientId', full_name='dashborg.rpc1.StartStreamMessage.FeClientId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ExistingReqId', full_name='dashborg.rpc1.StartStreamMessage.ExistingReqId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1782,
)


_STARTSTREAMRESPONSE = _descriptor.Descriptor(
  name='StartStreamResponse',
  full_name='dashborg.rpc1.StartStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.StartStreamResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.StartStreamResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='dashborg.rpc1.StartStreamResponse.ReqId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1784,
  serialized_end=1850,
)


_REFLECTZONEMESSAGE = _descriptor.Descriptor(
  name='ReflectZoneMessage',
  full_name='dashborg.rpc1.ReflectZoneMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.ReflectZoneMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1884,
)


_REFLECTZONERESPONSE = _descriptor.Descriptor(
  name='ReflectZoneResponse',
  full_name='dashborg.rpc1.ReflectZoneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.ReflectZoneResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.ReflectZoneResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.ReflectZoneResponse.JsonData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=1955,
)


_CALLDATAHANDLERMESSAGE = _descriptor.Descriptor(
  name='CallDataHandlerMessage',
  full_name='dashborg.rpc1.CallDataHandlerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.CallDataHandlerMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.CallDataHandlerMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.CallDataHandlerMessage.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.CallDataHandlerMessage.JsonData', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1957,
  serialized_end=2044,
)


_CALLDATAHANDLERRESPONSE = _descriptor.Descriptor(
  name='CallDataHandlerResponse',
  full_name='dashborg.rpc1.CallDataHandlerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.CallDataHandlerResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.CallDataHandlerResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='JsonData', full_name='dashborg.rpc1.CallDataHandlerResponse.JsonData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2119,
)


_BACKENDPUSHMESSAGE = _descriptor.Descriptor(
  name='BackendPushMessage',
  full_name='dashborg.rpc1.BackendPushMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Ts', full_name='dashborg.rpc1.BackendPushMessage.Ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PanelName', full_name='dashborg.rpc1.BackendPushMessage.PanelName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Path', full_name='dashborg.rpc1.BackendPushMessage.Path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2186,
)


_BACKENDPUSHRESPONSE = _descriptor.Descriptor(
  name='BackendPushResponse',
  full_name='dashborg.rpc1.BackendPushResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Success', full_name='dashborg.rpc1.BackendPushResponse.Success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Err', full_name='dashborg.rpc1.BackendPushResponse.Err', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2188,
  serialized_end=2239,
)

_SENDRESPONSEMESSAGE.fields_by_name['Actions'].message_type = _RRACTION
_REQUESTMESSAGE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_REGISTERHANDLERMESSAGE.fields_by_name['Handlers'].message_type = _HANDLERKEY
_REGISTERHANDLERRESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_PROCMESSAGE_PROCTAGSENTRY.containing_type = _PROCMESSAGE
_PROCMESSAGE_HOSTDATAENTRY.containing_type = _PROCMESSAGE
_PROCMESSAGE.fields_by_name['ProcTags'].message_type = _PROCMESSAGE_PROCTAGSENTRY
_PROCMESSAGE.fields_by_name['HostData'].message_type = _PROCMESSAGE_HOSTDATAENTRY
_PROCMESSAGE.fields_by_name['Handlers'].message_type = _HANDLERKEY
_PROCRESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
_SENDRESPONSERESPONSE.fields_by_name['ErrCode'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['RRAction'] = _RRACTION
DESCRIPTOR.message_types_by_name['SendResponseMessage'] = _SENDRESPONSEMESSAGE
DESCRIPTOR.message_types_by_name['RequestMessage'] = _REQUESTMESSAGE
DESCRIPTOR.message_types_by_name['HandlerKey'] = _HANDLERKEY
DESCRIPTOR.message_types_by_name['RegisterHandlerMessage'] = _REGISTERHANDLERMESSAGE
DESCRIPTOR.message_types_by_name['RegisterHandlerResponse'] = _REGISTERHANDLERRESPONSE
DESCRIPTOR.message_types_by_name['ProcMessage'] = _PROCMESSAGE
DESCRIPTOR.message_types_by_name['ProcResponse'] = _PROCRESPONSE
DESCRIPTOR.message_types_by_name['RequestStreamMessage'] = _REQUESTSTREAMMESSAGE
DESCRIPTOR.message_types_by_name['SendResponseResponse'] = _SENDRESPONSERESPONSE
DESCRIPTOR.message_types_by_name['StartStreamMessage'] = _STARTSTREAMMESSAGE
DESCRIPTOR.message_types_by_name['StartStreamResponse'] = _STARTSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReflectZoneMessage'] = _REFLECTZONEMESSAGE
DESCRIPTOR.message_types_by_name['ReflectZoneResponse'] = _REFLECTZONERESPONSE
DESCRIPTOR.message_types_by_name['CallDataHandlerMessage'] = _CALLDATAHANDLERMESSAGE
DESCRIPTOR.message_types_by_name['CallDataHandlerResponse'] = _CALLDATAHANDLERRESPONSE
DESCRIPTOR.message_types_by_name['BackendPushMessage'] = _BACKENDPUSHMESSAGE
DESCRIPTOR.message_types_by_name['BackendPushResponse'] = _BACKENDPUSHRESPONSE
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RRAction = _reflection.GeneratedProtocolMessageType('RRAction', (_message.Message,), {
  'DESCRIPTOR' : _RRACTION,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RRAction)
  })
_sym_db.RegisterMessage(RRAction)

SendResponseMessage = _reflection.GeneratedProtocolMessageType('SendResponseMessage', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESPONSEMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.SendResponseMessage)
  })
_sym_db.RegisterMessage(SendResponseMessage)

RequestMessage = _reflection.GeneratedProtocolMessageType('RequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RequestMessage)
  })
_sym_db.RegisterMessage(RequestMessage)

HandlerKey = _reflection.GeneratedProtocolMessageType('HandlerKey', (_message.Message,), {
  'DESCRIPTOR' : _HANDLERKEY,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.HandlerKey)
  })
_sym_db.RegisterMessage(HandlerKey)

RegisterHandlerMessage = _reflection.GeneratedProtocolMessageType('RegisterHandlerMessage', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERHANDLERMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RegisterHandlerMessage)
  })
_sym_db.RegisterMessage(RegisterHandlerMessage)

RegisterHandlerResponse = _reflection.GeneratedProtocolMessageType('RegisterHandlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERHANDLERRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RegisterHandlerResponse)
  })
_sym_db.RegisterMessage(RegisterHandlerResponse)

ProcMessage = _reflection.GeneratedProtocolMessageType('ProcMessage', (_message.Message,), {

  'ProcTagsEntry' : _reflection.GeneratedProtocolMessageType('ProcTagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCMESSAGE_PROCTAGSENTRY,
    '__module__' : 'dborgproto_pb2'
    # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage.ProcTagsEntry)
    })
  ,

  'HostDataEntry' : _reflection.GeneratedProtocolMessageType('HostDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCMESSAGE_HOSTDATAENTRY,
    '__module__' : 'dborgproto_pb2'
    # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage.HostDataEntry)
    })
  ,
  'DESCRIPTOR' : _PROCMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcMessage)
  })
_sym_db.RegisterMessage(ProcMessage)
_sym_db.RegisterMessage(ProcMessage.ProcTagsEntry)
_sym_db.RegisterMessage(ProcMessage.HostDataEntry)

ProcResponse = _reflection.GeneratedProtocolMessageType('ProcResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ProcResponse)
  })
_sym_db.RegisterMessage(ProcResponse)

RequestStreamMessage = _reflection.GeneratedProtocolMessageType('RequestStreamMessage', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSTREAMMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.RequestStreamMessage)
  })
_sym_db.RegisterMessage(RequestStreamMessage)

SendResponseResponse = _reflection.GeneratedProtocolMessageType('SendResponseResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDRESPONSERESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.SendResponseResponse)
  })
_sym_db.RegisterMessage(SendResponseResponse)

StartStreamMessage = _reflection.GeneratedProtocolMessageType('StartStreamMessage', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAMMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.StartStreamMessage)
  })
_sym_db.RegisterMessage(StartStreamMessage)

StartStreamResponse = _reflection.GeneratedProtocolMessageType('StartStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTSTREAMRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.StartStreamResponse)
  })
_sym_db.RegisterMessage(StartStreamResponse)

ReflectZoneMessage = _reflection.GeneratedProtocolMessageType('ReflectZoneMessage', (_message.Message,), {
  'DESCRIPTOR' : _REFLECTZONEMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ReflectZoneMessage)
  })
_sym_db.RegisterMessage(ReflectZoneMessage)

ReflectZoneResponse = _reflection.GeneratedProtocolMessageType('ReflectZoneResponse', (_message.Message,), {
  'DESCRIPTOR' : _REFLECTZONERESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.ReflectZoneResponse)
  })
_sym_db.RegisterMessage(ReflectZoneResponse)

CallDataHandlerMessage = _reflection.GeneratedProtocolMessageType('CallDataHandlerMessage', (_message.Message,), {
  'DESCRIPTOR' : _CALLDATAHANDLERMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.CallDataHandlerMessage)
  })
_sym_db.RegisterMessage(CallDataHandlerMessage)

CallDataHandlerResponse = _reflection.GeneratedProtocolMessageType('CallDataHandlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALLDATAHANDLERRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.CallDataHandlerResponse)
  })
_sym_db.RegisterMessage(CallDataHandlerResponse)

BackendPushMessage = _reflection.GeneratedProtocolMessageType('BackendPushMessage', (_message.Message,), {
  'DESCRIPTOR' : _BACKENDPUSHMESSAGE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.BackendPushMessage)
  })
_sym_db.RegisterMessage(BackendPushMessage)

BackendPushResponse = _reflection.GeneratedProtocolMessageType('BackendPushResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKENDPUSHRESPONSE,
  '__module__' : 'dborgproto_pb2'
  # @@protoc_insertion_point(class_scope:dashborg.rpc1.BackendPushResponse)
  })
_sym_db.RegisterMessage(BackendPushResponse)


DESCRIPTOR._options = None
_PROCMESSAGE_PROCTAGSENTRY._options = None
_PROCMESSAGE_HOSTDATAENTRY._options = None

_DASHBORGSERVICE = _descriptor.ServiceDescriptor(
  name='DashborgService',
  full_name='dashborg.rpc1.DashborgService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2370,
  serialized_end=3098,
  methods=[
  _descriptor.MethodDescriptor(
    name='Proc',
    full_name='dashborg.rpc1.DashborgService.Proc',
    index=0,
    containing_service=None,
    input_type=_PROCMESSAGE,
    output_type=_PROCRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendResponse',
    full_name='dashborg.rpc1.DashborgService.SendResponse',
    index=1,
    containing_service=None,
    input_type=_SENDRESPONSEMESSAGE,
    output_type=_SENDRESPONSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterHandler',
    full_name='dashborg.rpc1.DashborgService.RegisterHandler',
    index=2,
    containing_service=None,
    input_type=_REGISTERHANDLERMESSAGE,
    output_type=_REGISTERHANDLERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartStream',
    full_name='dashborg.rpc1.DashborgService.StartStream',
    index=3,
    containing_service=None,
    input_type=_STARTSTREAMMESSAGE,
    output_type=_STARTSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReflectZone',
    full_name='dashborg.rpc1.DashborgService.ReflectZone',
    index=4,
    containing_service=None,
    input_type=_REFLECTZONEMESSAGE,
    output_type=_REFLECTZONERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallDataHandler',
    full_name='dashborg.rpc1.DashborgService.CallDataHandler',
    index=5,
    containing_service=None,
    input_type=_CALLDATAHANDLERMESSAGE,
    output_type=_CALLDATAHANDLERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackendPush',
    full_name='dashborg.rpc1.DashborgService.BackendPush',
    index=6,
    containing_service=None,
    input_type=_BACKENDPUSHMESSAGE,
    output_type=_BACKENDPUSHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestStream',
    full_name='dashborg.rpc1.DashborgService.RequestStream',
    index=7,
    containing_service=None,
    input_type=_REQUESTSTREAMMESSAGE,
    output_type=_REQUESTMESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DASHBORGSERVICE)

DESCRIPTOR.services_by_name['DashborgService'] = _DASHBORGSERVICE

# @@protoc_insertion_point(module_scope)
